<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>InsertScriptItem</name>
    <message>
        <source>Position</source>
        <translation type="vanished">Positie</translation>
    </message>
    <message>
        <location filename="../InsertScriptItemInit.js" line="+2"/>
        <source>Insert &amp;Script</source>
        <translation>&amp;Script invoegen</translation>
    </message>
</context>
</TS>
